@@ -84,6 +84,9 @@ impl Driver {
             if e.raw_os_error() == Some(libc::EBUSY) {
                 return Ok(());
             }
+            if e.kind() == io::ErrorKind::Interrupted {
+                return Ok(());
+            }
             return Err(e);
         }
 
@@ -102,7 +105,7 @@ impl Driver {
     }
 
     pub(crate) fn with<T>(&self, f: impl FnOnce() -> T) -> T {
-        CURRENT.set(&self, f)
+        CURRENT.set(self, f)
     }
 
     fn provide_buffers(&mut self) -> io::Result<()> {
